@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate;
-$Web::Authenticate::VERSION = '0.009';
+$Web::Authenticate::VERSION = '0.012';
 use Mouse;
 use Carp;
 use Web::Authenticate::Cookie::Handler;
@@ -229,7 +229,10 @@ sub is_authenticated {
     my $session = $self->session_handler->get_session;
 
     unless ($session) {
-        if ($self->allow_after_login_redirect_override) {
+        my $allow_after_login_redirect_override =
+            exists $params{allow_after_login_redirect_override}
+            ? $params{allow_after_login_redirect_override} : $self->allow_after_login_redirect_override;
+        if ($allow_after_login_redirect_override) {
             my $url = $self->request_url_provider->url;
             $self->cookie_handler->set_cookie($self->_after_login_redirect_override_cookie_name, $url, $self->allow_after_login_redirect_time_seconds);
         }
@@ -258,7 +261,7 @@ sub check_for_session {
     my $self = shift;
     my %params = @_;
 
-    my $result = $self->is_authenticated;
+    my $result = $self->is_authenticated(allow_after_login_redirect_override => undef);
 
     return Web::Authenticate::Result::CheckForSession->new(success => undef) unless $result->success;
 
@@ -347,7 +350,7 @@ Web::Authenticate - Allows web authentication using cookies and a storage engine
 
 =head1 VERSION
 
-version 0.009
+version 0.012
 
 =head1 SYNOPSIS
 
@@ -588,6 +591,10 @@ authenticate, then the user will be redirected to L</authenticate_fail_url>.
 
 B<redirect (optional)> - If set to true, this method will redirect appropriately if the user does not authenticate.
 
+=item
+
+B<allow_after_login_redirect_override (optional)> - Can override L</allow_after_login_redirect_override> for this call. Defaults to L</allow_after_login_redirect_override>.
+
 =back
 
 First makes sure that the user authenticates as being logged in with a session. If the user is not, the user is redirected to L</login_url> if redirect is set to 1.
