@@ -1,6 +1,6 @@
 use strict;
 package Web::Authenticate::Session::Handler;
-$Web::Authenticate::Session::Handler::VERSION = '0.009';
+$Web::Authenticate::Session::Handler::VERSION = '0.012';
 use Mouse;
 use Carp;
 use DateTime;
@@ -58,9 +58,9 @@ sub create_session {
 
 
 sub delete_session {
-    my ($self) = @_;
+    my ($self, $session_id) = @_;
 
-    my $session_id = $self->_get_session_id;
+    $session_id ||= $self->_get_session_id;
     return unless $session_id;
 
     $self->session_storage_handler->delete_session($session_id);
@@ -105,8 +105,7 @@ sub get_session {
     my $session = $self->session_storage_handler->load_session($session_id);
 
     unless ($session) {
-        $self->session_storage_handler->delete_session($session_id);
-        $self->_delete_session_cookie;
+        $self->delete_session($session_id);
     }
 
     return $session;
@@ -146,7 +145,7 @@ Web::Authenticate::Session::Handler - The default implementation of Web::Authent
 
 =head1 VERSION
 
-version 0.009
+version 0.012
 
 =head1 METHODS
 
